document.addEventListener('DOMContentLoaded', () => {
  const activities = [];
  const activityForm = document.getElementById('activity-form');
  const activitiesContainer = document.querySelector('.activities-container');

  activityForm.addEventListener('submit', (e) => {
    e.preventDefault();
    const activity = {
      name: document.getElementById('activity-name').value,
      location: document.getElementById('activity-location').value,
      category: document.getElementById('activity-category').value,
      cost: document.getElementById('activity-cost').value,
      scores: [],
      averageScore: 0
    };
    
    activities.push(activity);
    renderActivities();
    activityForm.reset();
  });

  function renderActivities() {
    activitiesContainer.innerHTML = '';
    activities.forEach((activity, index) => {
      const card = document.createElement('div');
      card.className = 'activity-card';
      card.innerHTML = `
        <h3>${activity.name}</h3>
        <p>Location: ${activity.location}</p>
        <p>Category: ${activity.category}</p>
        <p>Cost: $${activity.cost}</p>
        <div class="rating-container">
          ${generateStarRating(index)}
        </div>
        <p class="average-score">Average Score: ${activity.averageScore.toFixed(1)}</p>
      `;
      activitiesContainer.appendChild(card);
      
      // Add event listeners to stars
      const stars = card.querySelectorAll('.rating-star');
      stars.forEach((star, starIndex) => {
        star.addEventListener('click', () => rateActivity(index, starIndex + 1));
      });
    });
    
    updateChart();
  }

  function generateStarRating(activityIndex) {
    return Array(5).fill(0).map((_, i) => 
      `<span class="rating-star ${activities[activityIndex].scores.includes(i + 1) ? 'active' : ''}" data-value="${i + 1}">★</span>`
    ).join('');
  }

  function rateActivity(activityIndex, score) {
    activities[activityIndex].scores.push(score);
    activities[activityIndex].averageScore = 
      activities[activityIndex].scores.reduce((a, b) => a + b, 0) / 
      activities[activityIndex].scores.length;
    renderActivities();
  }

  function updateChart() {
    const canvas = document.getElementById('score-chart');
    const ctx = canvas.getContext('2d');
    
    // Clear previous chart
    ctx.clearRect(0, 0, canvas.width, canvas.height);
    
    // Set canvas size
    canvas.width = 600;
    canvas.height = 400;
    
    // Draw chart
    if (activities.length > 0) {
      const barWidth = (canvas.width - 100) / activities.length;
      const maxScore = 5;
      
      activities.forEach((activity, index) => {
        const barHeight = (activity.averageScore / maxScore) * (canvas.height - 100);
        const x = 50 + (index * barWidth);
        const y = canvas.height - 50;
        
        // Draw bar
        ctx.fillStyle = '#e74c3c';
        ctx.fillRect(x, y - barHeight, barWidth - 10, barHeight);
        
        // Draw label
        ctx.fillStyle = '#2c3e50';
        ctx.font = '12px Arial';
        ctx.textAlign = 'center';
        ctx.fillText(activity.name, x + (barWidth - 10) / 2, y + 20);
      });
      
      // Draw y-axis
      ctx.beginPath();
      ctx.moveTo(40, 50);
      ctx.lineTo(40, canvas.height - 50);
      ctx.stroke();
      
      // Draw x-axis
      ctx.beginPath();
      ctx.moveTo(40, canvas.height - 50);
      ctx.lineTo(canvas.width - 40, canvas.height - 50);
      ctx.stroke();
    }
  }
});
